@@ -1,11 +1,20 @@
 
 loadModule("spat", TRUE)
 
+gdal_version <- function() {
+	.gdalversion()
+}
+
 .onAttach <- function(libname, pkgname) {
 	tv <- utils::packageVersion("terra")
-	m <- paste0("This is version ", tv, " of the \"terra\" package, for evaluation only\n")
+	m <- paste("This is terra version", tv, "(alpha-release)")
+	gdv <- gdal_version()
+	if (gdv < "3.0.0") {
+		a <- paste("\n\nNOTE: You are using GDAL version", gdv, "\nFor full functionality you need at least version 3.0.0\n")
+		m <- c(m, a)
+	}
 	packageStartupMessage(m)
-	
+
 ##############################
 	.create_options()
 	
@@ -13,6 +22,7 @@ loadModule("spat", TRUE)
 	if (file.exists(system.file("proj/nad.lst", package = "terra")[1])) {
 		path <- system.file("proj", package="terra")
 	} 
-	SpatRaster$new()$spatinit(path)
+	s <- SpatRaster$new()
+	s$spatinit(path)
 }
 
