@@ -11,6 +11,15 @@ std::string ginfo(std::string filename, std::vector<std::string> options, std::v
 	return out;
 }
 
+// [[Rcpp::export(name = ".gdalversion")]]
+std::string gdal_version() {
+	const char* what = "RELEASE_NAME";
+	const char* x = GDALVersionInfo(what);
+	std::string s = (std::string) x;
+	return s;
+}
+
+
 /*
 # include "warp.h"
 // [[Rcpp::export(name = ".gdalwarp")]]
@@ -194,7 +203,8 @@ RCPP_MODULE(spat){
 		.method("as_points", &SpatVector::as_points, "as_points")
 		.method("couldBeLonLat", &SpatVector::could_be_lonlat, "couldBeLonLat") 
 		.method("get_crs", &SpatVector::getSRS)
-		.method("set_crs", &SpatVector::setSRS)
+		
+		.method("set_crs", (bool (SpatVector::*)(std::string crs))( &SpatVector::setSRS))
 		//.method("p	rj", &SpatVector::getPRJ)
 		
 		.method("distance_self", (SpatDataFrame (SpatVector::*)())( &SpatVector::distance))
@@ -252,7 +262,7 @@ RCPP_MODULE(spat){
 		.constructor()
 	    //.constructor<std::string>()
 	    .constructor<std::vector<std::string> >()
-		.constructor<std::vector<unsigned>, std::vector<double>, std::vector<std::string>>()
+		.constructor<std::vector<unsigned>, std::vector<double>, std::string>()
 
 
 		.method("copy", &SpatRaster::deepCopy, "deepCopy")
@@ -265,7 +275,8 @@ RCPP_MODULE(spat){
 		.method("couldBeLonLat", &SpatRaster::could_be_lonlat, "couldBeLonLat") 
 		.method("copy", &SpatRaster::deepCopy, "deepCopy")
 		.method("get_crs", &SpatRaster::getSRS)
-		.method("set_crs", &SpatRaster::setSRS)
+
+		.method("set_crs", (bool (SpatRaster::*)(std::string crs))( &SpatRaster::setSRS))
 		//.field_readonly("prj", &SpatRaster::prj)
 		.property("extent", &SpatRaster::getExtent, &SpatRaster::setExtent )
 		.method("getRasterAtt", &getRasterAttributes, "get attributes")
@@ -383,8 +394,8 @@ RCPP_MODULE(spat){
 		.method("math2", &SpatRaster::math2, "math2")
 		.method("modal", &SpatRaster::modal, "modal")
 		.method("quantile", &SpatRaster::quantile, "quantile")
+		//.method("rasterize", &SpatRaster::rasterize, "rasterize")
 		.method("rasterize", &SpatRaster::rasterize, "rasterize")
-		.method("grasterize", &SpatRaster::grasterize, "grasterize")
 		.method("rotate", &SpatRaster::rotate, "rotate")
 		.method("sampleRegularRaster", &SpatRaster::sampleRegularRaster, "sampleRegular")	
 		.method("sampleRegularValues", &SpatRaster::sampleRegularValues, "sampleValues")	
