@@ -47,7 +47,7 @@ SpatRaster SpatRaster::distance(SpatVector p, SpatOptions &opt) {
 	if (gtype != "points") {
 		SpatOptions ops;
 		std::vector<double> feats(p.size(), 1) ;
-		SpatRaster x = rasterize(p, feats, NAN, false, ops);
+		SpatRaster x = rasterize(p, "", feats, NAN, false, false, false, ops);
 		if (gtype == "polygons") {
 			std::string etype = "inner";
 			x = x.edges(false, etype, 8, ops);
@@ -120,8 +120,8 @@ SpatDataFrame SpatVector::distance() {
 		out.setError("only inmplemented for points --- to be improved");
 		return(out);
 	}
-	std::vector<std::string> srs = getSRS();
-	if (srs[1] == "") {
+	std::string srs = getSRS("wkt");
+	if (srs == "") {
 		out.setError("SRS not defined");
 		return(out);
 	}
