@@ -46,8 +46,8 @@ SpatVector SpatVector::make_valid() {
 	OGRFeature *inFeature;
 	while( (inFeature = inLayer->GetNextFeature()) != NULL ) {
 		OGRGeometry *poGeometry = inFeature->GetGeometryRef();
-		OGRGeometry *poGeom = poGeometry->MakeValid();
-		if (inFeature->SetGeometry( poGeom ) != OGRERR_NONE) {
+		//OGRGeometry *poGeom = poGeometry->MakeValid();
+		if (inFeature->SetGeometry( poGeometry ) != OGRERR_NONE) {
 			out.setError("cannot set geometry");
 			return out;
 		}
